﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using System.Collections.ObjectModel;
using Microsoft.Phone.Net.NetworkInformation;
using Microsoft.Phone.Tasks;

namespace Phone7
{
    public partial class Page1 : PhoneApplicationPage
    {

        public ObservableCollection<string> Changes { get; set; }

        public ObservableCollection<string> NetworkInterfaces { get; set; }

        public Page1()
        {
            InitializeComponent();


            // 网络可用性改变事件日志
            Changes = new ObservableCollection<string>();
            lbNetworkChanges.DataContext = Changes;

            //当前可用的网络接口
            NetworkInterfaces = new ObservableCollection<string>();
            lbNetworkInterfaces.DataContext = NetworkInterfaces;
            //网络可用性改变时
            DeviceNetworkInformation.NetworkAvailabilityChanged += new EventHandler<NetworkNotificationEventArgs>(ChangeDetected);

            UpdateNetworkInterfaces();
            UpdateNetworkStatus();
        }

        void ChangeDetected(object sender, NetworkNotificationEventArgs e)
        {
            string change = string.Empty;
            switch (e.NotificationType)
            {
                case NetworkNotificationType.InterfaceConnected:
                    change = "连接: ";
                    break;
                case NetworkNotificationType.InterfaceDisconnected:
                    change = "断开: ";
                    break;
                case NetworkNotificationType.CharacteristicUpdate:
                    change = "变更: ";
                    break;
                default:
                    change = "未知: ";
                    break;
            }

            string changeInformation = String.Format(" {0} {1} {2} ({3})",
                        DateTime.Now.ToShortTimeString(), change, e.NetworkInterface.InterfaceName,
                        InterfaceTypeConvert.Convert(e.NetworkInterface.InterfaceType) + "," + InterfaceTypeConvert.ConvertSub(e.NetworkInterface.InterfaceSubtype));

            Dispatcher.BeginInvoke(() =>
            {
                Changes.Add(changeInformation);
                UpdateNetworkStatus();
                UpdateNetworkInterfaces();

            });

        }

        //更新网络接口
        private void UpdateNetworkInterfaces()
        {

            NetworkInterfaces.Clear();
            //获取网络接口列表
            NetworkInterfaceList networkInterfaceList = new NetworkInterfaceList();
            foreach (NetworkInterfaceInfo networkInterfaceInfo in networkInterfaceList)
            {
                NetworkInterfaces.Add(String.Format("{0} ({1},{2})",
                    networkInterfaceInfo.InterfaceName,
                    InterfaceTypeConvert.Convert(networkInterfaceInfo.InterfaceType),
                    InterfaceTypeConvert.ConvertSub(networkInterfaceInfo.InterfaceSubtype)));
            }
        }

        //更新网络状态
        private void UpdateNetworkStatus()
        {
            tbIsCellularDataEnabled.Text = (DeviceNetworkInformation.IsCellularDataEnabled) ? "是" : "否";
            tbIsNetworkAvailable.Text = (DeviceNetworkInformation.IsNetworkAvailable) ? "是" : "否";
            tbIsWiFiEnabled.Text = (DeviceNetworkInformation.IsWiFiEnabled) ? "是" : "否";
        }

        //连接设置
        private void Button_Click_3(object sender, RoutedEventArgs e)
        {
            var settringTypeString = string.Empty;
            var button = sender as Button;
            if (button != null) settringTypeString = Convert.ToString(button.Content);
            var settringType = ConnectionSettingsType.WiFi;
            switch (settringTypeString)
            {
                case "飞行": settringType = ConnectionSettingsType.AirplaneMode;
                    break;
                case "网络": settringType = ConnectionSettingsType.Cellular;
                    break;
                case "蓝牙": settringType = ConnectionSettingsType.Bluetooth;
                    break;
                default: break;
            }

            //连接设置选择框
            ConnectionSettingsTask connectionSettings = new ConnectionSettingsTask();

            // 连接设置的类型
            connectionSettings.ConnectionSettingsType = settringType;
            connectionSettings.Show();
        }

        //刷新
        private void Button_Click_2(object sender, RoutedEventArgs e)
        {
            UpdateNetworkStatus();
            UpdateNetworkInterfaces();
            Changes.Clear();
        }

        private void Button_Click_1(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new Uri("/MainPage.xaml", UriKind.Relative));
        }

    }
}